@@ -1,4 +1,4 @@
-use super::extra::*;
+use super::components::*;
 use serde::{Deserialize, Serialize};
 use std::fs;
 
