@@ -14,6 +14,10 @@ impl BacklightFormatter {
     pub fn set_percentage(&mut self, p: usize) {
         self.percentage = p;
     }
+
+    pub fn get_percentage(&self) -> String {
+        format!("{}%", self.percentage)
+    }
 }
 
 impl Iconize for BacklightFormatter {
@@ -24,6 +28,6 @@ impl Iconize for BacklightFormatter {
 
 impl fmt::Display for BacklightFormatter {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        return write!(f, "{}%", self.percentage);
+        return write!(f, "{}", self.get_percentage());
     }
 }
