@@ -1,5 +1,5 @@
-use crate::config::Config;
 use crate::options::Command;
+use crate::Config;
 use crate::Icon;
 
 use libmacchina::traits::ReadoutError;
